==> Apllepy_personal_assistant-0.1.1.tar.gz: Apllepy_personal_assistant-0.1.1/README.md <==
# $\color{red}{Welcome}$ $\color{red}{to}$ $\color{red}{your}$ $\color{red}{ApplePy}$ $\color{red}{Personal}$ $\color{red}{Assistant}$

<img src="ApplePy.PNG" align="center" style="width: 860px"  />

### I'm you Personal Assistant bot. _I was created by a group of Python enthusiasts to make your life easier_.

---

## What I can to do:

You as a user have the option to use **Address Book**, **Notebook** or a **File Sorter**.

$\color{blue}{Address Book}$ you can operate the following features:

- add contacts with the name and a phone number
- change contact's phone number
- add birthday, email address and address to the contacts
- count the number of days that are left to the contact's birthday
- display a singular contact details or all contacts
- look up the specific contacts by a part of the number or name

$\color{purple}{Notebook}$ the following operations are available:

- add notes with text and tags
- search notes by tags
- adjust/update/correct notes

$\color{green}{File Sorter}$ will sort your files into the folders according to their extensions. In order to start the File sorter - please provide the path to the folder you wish to sort.

## How can you install me:

OS X & Linux:

```
pip install -e
or
pip install -i https://test.pypi.org/simple/ {add name of the file from Pypi}
```

Windows:

```
pip install
or
pip install -i https://test.pypi.org/simple/ {add name of the file from Pypi}
```

## What if I do not know what to do?

> In case you need additional help on how to word your requests - please type 'help' and the bot will present you with all the available options :wink:

---

### Project creators:

- **Igor Pupynin** -- Team and Inspirational Leader, who worked on Address Book, promt_toolkit-2 and put the script together;
- **Tatiana Shevtsova** -- Python developer, who worked on File Sorter and Notebook Classes and mental support for the whole team;
- **Andriy Svitelskyi** -- Python developer, who worked on perfecting File Sorter, creating Notebook and gushed with ideas regarding the project as a whole;
- **Valentyna Gordynska** -- Scrum Master, who worked with Address book and organized/scheduled the workflow;

### General:

Link to pip packet: [ApplePy](insert link to Pypi)

pip install command:
`pip install -i https://test.pypi.org/simple/ insert project name from Pypi`

[![Language](https://img.shields.io/badge/language-python-blue?&style=plastic)](https://www.python.org)
[![Language version](https://img.shields.io/badge/version-3.10-red?&style=plastic)](https://www.python.org/downloads/)
![GitHub Release Date](https://img.shields.io/badge/release--date-31.01.2023-orange?&style=plastic)

==> Apllepy_personal_assistant-0.1.6.tar.gz: Apllepy_personal_assistant-0.1.6/README.md <==
# $\color{red}{Welcome}$ $\color{red}{to}$ $\color{red}{your}$ $\color{red}{ApplePy}$ $\color{red}{Personal}$ $\color{red}{Assistant}$

<img src="ApplePy.PNG" align="center" style="width: 860px"  />

### I'm you Personal Assistant bot. _I was created by a group of Python enthusiasts to make your life easier_.

---

## What I can to do:

You as a user have the option to use **Address Book**, **Notebook** or a **File Sorter**.

Once the bot is inatalled you call it by typing **console-bot** in the terminal.

$\color{blue}{Address Book}$ you can operate the following features:

- add contacts with the name and a phone number
- change contact's phone number
- add birthday, email address and address to the contacts
- count the number of days that are left to the contact's birthday
- display a singular contact details or all contacts
- look up the specific contacts by a part of the number or name

$\color{purple}{Notebook}$ the following operations are available:

- add notes with text and tags
- search notes by tags
- adjust/update/correct notes

$\color{green}{File Sorter}$ will sort your files into the folders according to their extensions. In order to start the File sorter - please provide the path to the folder you wish to sort.

## How can you install me:

OS X & Linux:

```
pip install -e Apllepy-personal-assistant==0.1.5
or
pip install -i https://test.pypi.org/simple/ (Apllepy-personal-assistant==0.1.5)
```

Windows:

```
pip install Apllepy-personal-assistant==0.1.5
or
pip install -i https://test.pypi.org/simple/ (Apllepy-personal-assistant==0.1.5)
```

## What if I do not know what to do?

> In case you need additional help on how to word your requests - please type 'help' and the bot will present you with all the available options :wink:

---

### Project creators:

- **Igor Pupynin** -- Team and Inspirational Leader, who worked on Address Book, promt_toolkit-2 and put the script together;
- **Tatiana Shevtsova** -- Python developer, who worked on File Sorter and Notebook Classes and mental support for the whole team;
- **Andriy Svitelskyi** -- Python developer, who worked on perfecting File Sorter, creating Notebook and gushed with ideas regarding the project as a whole;
- **Valentyna Gordynska** -- Scrum Master, who worked with Address book and organized/scheduled the workflow;

### General:

Link to pip packet: [ApplePy](https://pypi.org/project/Apllepy-personal-assistant/)

pip install command:
`pip install Apllepy-personal-assistant==0.1.5`

[![Language](https://img.shields.io/badge/language-python-blue?&style=plastic)](https://www.python.org)
[![Language version](https://img.shields.io/badge/version-0.1.5-red?&style=plastic)](https://www.python.org/downloads/)
![GitHub Release Date](https://img.shields.io/badge/release--date-31.01.2023-orange?&style=plastic)
